Template View — Pyramid Class-Based Views 1.0 documentation

# Template View

class `pyramid_views.views.base.` `TemplateView`(**kwargs)

  A view that renders a template. This view will also pass into the context any keyword arguments passed by the url conf.

  `template_name` = None
  `content_type` = None
  `get_context_data`(**kwargs)
  `macro_names` = None
  `get_macro_names`()

    Return a directory of macro names.

    Values should be template paths, and keys will be used as the lookup key in the template. Eg. `macros.<key>.<macro>`.

  `get`(request, *args, **kwargs)